SpecialJumpKind

Enum SpecialJumpKind 

enum SpecialJumpKind {
    LoopContinue(usize),
    LoopBreak(usize),
    ForwardBreak(usize),
    NextBlock,
}

Variants



LoopContinue(usize)

This block can be reached by a continue to the given depth.



LoopBreak(usize)

This block can be reached by a break to the given depth. This comes from a loop.



ForwardBreak(usize)

This block can be reached by a break to the given depth. This is a loop context introduced only for forward jumps.



NextBlock

This block can be reached by doing nothing as this is the next block that will be translated. Only applies if this block is at the top of the stack.