pub struct DfsWithPath<N, VM> {
pub stack: Vec<StackAction<N>>,
pub discovered: VM,
pub path: Vec<N>,
}Fields
stack: Vec<StackAction<N>>The stack of nodes to visit
discovered: VMThe map of discovered nodes
path: Vec<N>The path from start node to current node.
Implementations
Sourceimpl<N, VM> DfsWithPath<N, VM>
impl<N, VM> DfsWithPath<N, VM>
Sourcepub fn new<G>(graph: G, start: N) -> Self
pub fn new<G>(graph: G, start: N) -> Self
Create a new DfsWithPath, using the graph’s visitor map, and put start in the stack of nodes to visit.
Sourcepub fn next<G>(&mut self, graph: G) -> Option<N>where
G: IntoNeighbors<NodeId = N>,
pub fn next<G>(&mut self, graph: G) -> Option<N>where
G: IntoNeighbors<NodeId = N>,
Return the next node in the dfs, or None if the traversal is done.