struct LoopExitRank {
is_unwind_block: Reverse<bool>,
path_count: usize,
distance_from_header: Reverse<usize>,
}Expand description
Fields
is_unwind_block: Reverse<bool>Prefer regular blocks over blocks reachable only through unwind edges.
path_count: usizeNumber of paths we found going to this exit.
distance_from_header: Reverse<usize>Distance from the loop header.