struct ReconstructCtx<'a> {
cfg: CfgInfo,
body: &'a ExprBody,
break_context_depth: usize,
special_jump_stack: Vec<SpecialJump>,
mode: ReconstructMode,
}Fields
cfg: CfgInfobody: &'a ExprBodybreak_context_depth: usizeThe depth of loop contexts we may break/continue to.
special_jump_stack: Vec<SpecialJump>Stack of block ids that should be translated to special jumps (break/continue/do
nothing) in the current context.
The block where control-flow continues naturally after this block is kept at the top of the
stack.
mode: ReconstructModeImplementations
Sourceimpl<'a> ReconstructCtx<'a>
impl<'a> ReconstructCtx<'a>
fn build( ctx: &TransformCtx, src_body: &'a ExprBody, ) -> Result<Self, Irreducible>
fn translate_statement(&self, st: &Statement) -> Statement
Sourcefn translate_jump(&mut self, span: Span, target_block: BlockId) -> Block
fn translate_jump(&mut self, span: Span, target_block: BlockId) -> Block
Translate a jump to the given block. The span is used to create the jump statement, if any.
fn translate_terminator(&mut self, terminator: &Terminator) -> Block
Sourcefn translate_block_itself(&mut self, block_id: BlockId) -> Block
fn translate_block_itself(&mut self, block_id: BlockId) -> Block
Translate just the block statements and terminator.
Sourcefn translate_block(&mut self, block_id: BlockId) -> Block
fn translate_block(&mut self, block_id: BlockId) -> Block
Translate a block including surrounding control-flow like looping.
fn translate_block_inner(&mut self, block_id: BlockId) -> Block